.. _AUTHORS:

Contributors
============

Development
~~~~~~~~~~~

* Rikard Nordgren, rikard.nordgren@farmaci.uu.se (maintainer)
* Stella Belin, stella.belin@farmaci.uu.se (maintainer)
* Zhe Huang, zhe.huang@farmaci.uu.se
* Gunnar Yngman, gunnar.yngman@farmaci.uu.se
* Kajsa Harling

Scientific input
~~~~~~~~~~~~~~~~

* Mats O. Karlsson
* Andrew C. Hooker
* Sebastian Ueckert
* Simon Carter
* Simon Buatois
* João A. Abrantes

Funding
~~~~~~~

A warm thanks to all our sponsors!

*  F\. Hoffman-La Roche Ltd.
*  Pharmetheus
*  Uppsala University
